﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Benday.FakesSample.DataAccess
{
    public class PersonDataAccess
    {
        public void SavePerson(FakesDataSet.PersonRow saveThis)
        {
            if (saveThis == null)
            {
                throw new ArgumentNullException("saveThis", "saveThis is null.");
            }

            using (var adapter = new FakesDataSetTableAdapters.PersonTableAdapter())
            {
                if (saveThis.RowState == System.Data.DataRowState.Added ||
                    String.Equals(
                        saveThis["EmailAddress", 
                            System.Data.DataRowVersion.Original], 
                        saveThis.EmailAddress) == false)
                {
                    // email address has been modified
                    var match = adapter.GetDataByEmailAddress(saveThis.EmailAddress);

                    if (match.Rows.Count != 0 && 
                        match[0].Id != saveThis.Id)
                    {
                        throw new InvalidOperationException(
                            "Cannot save a duplicate email address.");
                    }
                }

                adapter.Update(saveThis);
            }
        }

        public FakesDataSet.PersonRow LoadPerson(int id)
        {
            using (var adapter = new FakesDataSetTableAdapters.PersonTableAdapter())
            {
                var results = adapter.GetDataById(id);

                if (results.Rows.Count > 0)
                {
                    return results[0];
                }
                else
                {
                    return null;
                }
            }
        }        
    }
}
